# nbsvm-sklean

A Scikit-learn wrapper for the NBSVM algorithm. To read more about the same, go [here](https://www.aclweb.org/anthology/P12-2018)

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install nbsvm-sklearn.

```bash
pip install nbsvm-sklearn
```

## Usage

```python
import foobar

foobar.pluralize('word') # returns 'words'
foobar.pluralize('goose') # returns 'geese'
foobar.singularize('phenomena') # returns 'phenomenon'
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)
